@@ -28,6 +28,7 @@ SUCH DAMAGE.
 */
 #include <glib.h>
 #include <libintl.h>
+#include <locale.h>
 #include "complearn/newcomplearn.h"
 #include "complearn/clconfig.h"
 
@@ -463,11 +464,15 @@ const char *complearn_get_uts_name(void)
   return utsname;
 }
 
-GString *complearn_matrix_prettyprint_clb(LabeledMatrix *result) {
+GString *complearn_matrix_prettyprint_clb(LabeledMatrix *dm) {
   struct CLDistMatrix inp;
   memset(&inp, 0, sizeof(inp));
-  inp.m = result;
-  return clRealWriteCLBDistMatrix(&inp);
+  inp.m = dm;
+  char *old_locale = setlocale(LC_NUMERIC, NULL);
+  setlocale(LC_NUMERIC, "C");
+  GString *result = clRealWriteCLBDistMatrix(&inp);
+  setlocale(LC_NUMERIC, old_locale);
+  return result;
 }
 
 LabeledMatrix *complearn_load_any_matrix(const GString *inp)
